@@ -162,7 +162,7 @@ int Mixer_SUN::open()
      audiodev = "/dev/audio";
    audiodev += "ctl";
    _udi = audiodev; // use device name as UDI. Doesn't matter as we only use it for hotplugging/unplugging.
-   if ( ( fd = ::open( audiodev.toAscii().data(), O_RDWR ) ) < 0 )
+   if ( ( fd = ::open( audiodev.toLatin1().data(), O_RDWR ) ) < 0 )
    {
       if ( errno == EACCES )
          return Mixer::ERR_PERM;
