@@ -23,10 +23,7 @@
 
 #include "gui/kmixdockwidget.h"
 
-#include <kaction.h>
-#include <klocale.h>
-#include <kmenu.h>
-#include <kdebug.h>
+#include <klocalizedstring.h>
 #include <kwindowsystem.h>
 #include <kactioncollection.h>
 #include <ktoggleaction.h>
@@ -36,6 +33,7 @@
 #include <QDesktopWidget>
 #include <QAction>
 #include <QApplication>
+#include <QMenu>
 #include <QTextDocument>
 
 #include "apps/kmix.h"
@@ -70,8 +68,8 @@ KMixDockWidget::KMixDockWidget(KMixWindow* parent)
     connect(this, SIGNAL(scrollRequested(int,Qt::Orientation)), this, SLOT(trayWheelEvent(int,Qt::Orientation)));
     connect(this, SIGNAL(secondaryActivateRequested(QPoint)), this, SLOT(dockMute()));
 
-	// For bizarre reasons, we wrap the ViewDockAreaPopup in a KMenu. Must relate to how KStatusNotifierItem works.
-   _dockAreaPopupMenuWrapper = new KMenu(parent);
+	// For bizarre reasons, we wrap the ViewDockAreaPopup in a QMenu. Must relate to how KStatusNotifierItem works.
+   _dockAreaPopupMenuWrapper = new QMenu(parent);
 	_volWA = new QWidgetAction(_dockAreaPopupMenuWrapper);
 	_dockView = new ViewDockAreaPopup(_dockAreaPopupMenuWrapper, "dockArea", 0, QString("no-guiprofile-yet-in-dock"), parent);
 	_volWA->setDefaultWidget(_dockView);
@@ -117,7 +115,7 @@ void KMixDockWidget::controlsChange(int changeType)
 		  }
 		  else
 		  {
-			  kWarning() << "select_master action not found. Cannot enable it in the Systray.";
+			  qCWarning(KMIX_LOG) << "select_master action not found. Cannot enable it in the Systray.";
 		  }
       }
       break;
@@ -133,7 +131,6 @@ void KMixDockWidget::controlsChange(int changeType)
 
 QAction* KMixDockWidget::findAction(const char* actionName)
 {
-#ifdef X_KMIX_KF5_BUILD
 	QList<QAction*> actions = actionCollection();
 	int size = actions.size();
 	for (int i=0; i<size; ++i)
@@ -142,11 +139,8 @@ QAction* KMixDockWidget::findAction(const char* actionName)
         if (action->data().toString() == QString::fromUtf8(actionName))
 			return action;
 	}
-    qWarning() << "ACTION" << actionName << "NOT FOUND!";
+    qCWarning(KMIX_LOG) << "ACTION" << actionName << "NOT FOUND!";
     return Q_NULLPTR;
-#else
-	return actionCollection()->action(QLatin1String(actionName));
-#endif
 }
 
 /**
@@ -170,28 +164,18 @@ void KMixDockWidget::createMenuActions()
     shared_ptr<MixDevice> md = Mixer::getGlobalMasterMD();
     if ( md.get() != 0 && md->hasMuteSwitch() ) {
         // Put "Mute" selector in context menu
-#ifdef X_KMIX_KF5_BUILD
         KToggleAction *action = new KToggleAction(i18n("M&ute"), this);
         action->setData("dock_mute");
         addAction("dock_mute", action);
-#else
-    	KToggleAction *action = actionCollection()->add<KToggleAction>( "dock_mute" );
-        action->setText( i18n("M&ute") );
-#endif
     	updateDockMuteAction(action);
         connect(action, SIGNAL(triggered(bool)), SLOT(dockMute()));
         menu->addAction( action );
     }
 
     // Put "Select Master Channel" dialog in context menu
-#ifdef X_KMIX_KF5_BUILD
     QAction *action = new QAction(i18n("Select Master Channel..."), this);
     action->setData("select_master");
     addAction("select_master", action);
-#else
-    QAction *action = actionCollection()->addAction( "select_master" );
-    action->setText( i18n("Select Master Channel...") );
-#endif
     action->setEnabled(Mixer::getGlobalMasterMixer() != 0);
     connect(action, SIGNAL(triggered(bool)), _kmixMainWindow, SLOT(slotSelectMaster()));
     menu->addAction( action );
@@ -222,7 +206,8 @@ KMixDockWidget::setVolumeTip()
         if ( md->isMuted() )
             tip += i18n( " (Muted)" );
         subTip = QString( "%1<br/>%2" )
-                 .arg( Qt::escape(md->mixer()->readableName()) ).arg( Qt::escape(md->readableName()) );
+		.arg(md->mixer()->readableName().toHtmlEscaped())
+		.arg(md->readableName().toHtmlEscaped());
 
         // create a new "virtual" value. With that we see "volume changes" as well as "muted changes"
         virtualToolTipValue = val;
@@ -321,26 +306,26 @@ void KMixDockWidget::activate(const QPoint &pos)
 	{
 		// move horizontally, so that it is completely visible
 		x = vScreenSize.width() + vScreenSize.x() - dockAreaPopup->width() - 1;
-		kDebug() << "Multihead: (case 1) moving to" << x << "," << y;
+		qCDebug(KMIX_LOG) << "Multihead: (case 1) moving to" << x << "," << y;
 	}
 	else if (x < vScreenSize.x())
 	{
 		// horizontally out-of bound
 		x = vScreenSize.x();
-		kDebug() << "Multihead: (case 2) moving to" << x << "," << y;
+		qCDebug(KMIX_LOG) << "Multihead: (case 2) moving to" << x << "," << y;
 	}
 
 	if ((y + dockAreaPopup->height()) > (vScreenSize.height() + vScreenSize.y()))
 	{
 		// move horizontally, so that it is completely visible
 		y = vScreenSize.height() + vScreenSize.y() - dockAreaPopup->height() - 1;
-		kDebug() << "Multihead: (case 3) moving to" << x << "," << y;
+		qCDebug(KMIX_LOG) << "Multihead: (case 3) moving to" << x << "," << y;
 	}
 	else if (y < vScreenSize.y())
 	{
 		// horizontally out-of bound
 		y = vScreenSize.y();
-		kDebug() << "Multihead: (case 4) moving to" << x << "," << y;
+		qCDebug(KMIX_LOG) << "Multihead: (case 4) moving to" << x << "," << y;
 	}
 
 
@@ -360,7 +345,7 @@ KMixDockWidget::trayWheelEvent(int delta,Qt::Orientation wheelOrientation)
 
 
 	Volume &vol = ( md->playbackVolume().hasVolume() ) ?  md->playbackVolume() : md->captureVolume();
-//	kDebug() << "I am seeing a wheel event with delta=" << delta << " and orientation=" <<  wheelOrientation;
+//	qCDebug(KMIX_LOG) << "I am seeing a wheel event with delta=" << delta << " and orientation=" <<  wheelOrientation;
 	if (wheelOrientation == Qt::Horizontal) // Reverse horizontal scroll: bko228780
 	{
 		delta = -delta;
@@ -384,7 +369,7 @@ KMixDockWidget::trayWheelEvent(int delta,Qt::Orientation wheelOrientation)
 	long cv = vol.volumeStep(decrease) * inc;
 
     bool isInactive =  vol.isCapture() ? !md->isRecSource() : md->isMuted();
-//    kDebug() << "Operating on capture=" << vol.isCapture() << ", isInactive=" << isInactive;
+//    qCDebug(KMIX_LOG) << "Operating on capture=" << vol.isCapture() << ", isInactive=" << isInactive;
 	if ( cv > 0 && isInactive)
 	{
 		// increasing from muted state: unmute and start with a low volume level
@@ -431,7 +416,7 @@ void KMixDockWidget::contextMenuAboutToShow()
 {
     // Enable/Disable "Muted" menu item
     KToggleAction *dockMuteAction = static_cast<KToggleAction*>(findAction("dock_mute"));
-    qDebug() << "DOCK MUTE" << dockMuteAction;
+    qCDebug(KMIX_LOG) << "DOCK MUTE" << dockMuteAction;
     if (dockMuteAction)
         updateDockMuteAction(dockMuteAction);
 }
