@@ -23,7 +23,6 @@
 #define KMIXPREFDLG_H
 
 #include <kconfigdialog.h>
-#include <kdialog.h>
 
 class KMixPrefWidget;
 
@@ -61,25 +60,25 @@ private slots:
 	void kmixConfigHasChangedEmitter();
 
 protected:
-	void showEvent(QShowEvent * event);
+	void showEvent(QShowEvent * event) Q_DECL_OVERRIDE;
 	/**
 	 * Orientation is not supported by default => implement manually
 	 * @Override
 	 */
-	void updateWidgets();
+	void updateWidgets() Q_DECL_OVERRIDE;
 	/**
 	 * Orientation is not supported by default => implement manually
 	 * @Override
 	 */
-	void updateSettings();
+	void updateSettings() Q_DECL_OVERRIDE;
 
-	bool hasChanged();
+	bool hasChanged() Q_DECL_OVERRIDE;
 
 private:
 	static KMixPrefDlg* instance;
 
 	KMixPrefDlg(QWidget *parent, GlobalConfig& config);
-	virtual ~KMixPrefDlg();
+	virtual ~KMixPrefDlg() = default;
 
 	enum KMixPrefDlgPrefOrientationType
 	{
