@@ -23,7 +23,6 @@
 #ifndef MDWSLIDER_H
 #define MDWSLIDER_H
 
-#include <KShortcut>
 #include "volumeslider.h"
 #include <QCheckBox>
 #include <QList>
@@ -34,10 +33,8 @@
 class QBoxLayout;
 class QToolButton;
 class QLabel;
+class QMenu;
 
-class KAction;
-class KMenu;
-#include <kshortcut.h>
 #include <kiconloader.h>
 
 class MixDevice;
@@ -60,28 +57,28 @@ public:
     virtual ~MDWSlider();
 
     enum LabelType { LT_ALL, LT_FIRST_CAPTURE, LT_NONE };
-    void addActionToPopup( KAction *action );
+    void addActionToPopup( QAction *action );
     void createActions();
     void createShortcutActions();
     
     // GUI
-    bool isStereoLinked() const { return m_linked; }
-    void setStereoLinked( bool value );
-    void setLabeled( bool value );
-    void setTicks( bool ticks );
-    void setIcons( bool value );
+    bool isStereoLinked() const Q_DECL_OVERRIDE { return m_linked; }
+    void setStereoLinked( bool value ) Q_DECL_OVERRIDE;
+    void setLabeled( bool value ) Q_DECL_OVERRIDE;
+    void setTicks( bool ticks ) Q_DECL_OVERRIDE;
+    void setIcons( bool value ) Q_DECL_OVERRIDE;
 //    void setIcon( QString filename, QLabel** label );
     void setIcon( QString filename, QWidget* label );
     QToolButton* addMediaButton(QString iconName, QLayout* layout, QWidget *parent);
     void updateMediaButton();
-    void setColors( QColor high, QColor low, QColor back );
-    void setMutedColors( QColor high, QColor low, QColor back );
+    void setColors( QColor high, QColor low, QColor back ) Q_DECL_OVERRIDE;
+    void setMutedColors( QColor high, QColor low, QColor back ) Q_DECL_OVERRIDE;
     
-    bool eventFilter( QObject* obj, QEvent* e );
+    bool eventFilter( QObject* obj, QEvent* e ) Q_DECL_OVERRIDE;
     QString iconName();
     // Layout
     QSizePolicy sizePolicy() const;
-	QSize sizeHint() const;
+	QSize sizeHint() const Q_DECL_OVERRIDE;
 	int labelExtentHint() const;
 	void setLabelExtent(int extent);
 	bool hasMuteButton() const;
@@ -98,19 +95,15 @@ public slots:
     void toggleMuted();
     void toggleStereoLinked();
 
-    void setDisabled( bool value );
-    void update();
+    void setDisabled( bool value ) Q_DECL_OVERRIDE;
+    void update() Q_DECL_OVERRIDE;
     void showMoveMenu();
-    virtual void showContextMenu( const QPoint &pos = QCursor::pos() );
+    void showContextMenu( const QPoint &pos = QCursor::pos() ) Q_DECL_OVERRIDE;
     void increaseOrDecreaseVolume(bool arg1, Volume::VolumeTypeFlag volumeType);
     VolumeSliderExtraData& extraData(QAbstractSlider *slider);
     void addMediaControls(QBoxLayout* arg1);
 
 
-signals:
-    void toggleMenuBar(bool value);
-    void guiVisibilityChange(MixDeviceWidget* source, bool enable);
-
 private slots:
     void setRecsrc( bool value );
     void setMuted(bool value);
@@ -129,7 +122,6 @@ private slots:
     void mediaPrev(bool);
 
 private:
-    KShortcut dummyShortcut;
     QPixmap loadIcon( QString filename, KIconLoader::Group group );
     void createWidgets( bool showMuteLED, bool showCaptureLED, bool includeMixer );
     void addSliders( QBoxLayout *volLayout, char type, Volume& vol,
@@ -176,7 +168,7 @@ private:
 	bool captureLEDSpacing;
 
     KActionCollection*   _mdwMoveActions;
-    KMenu *m_moveMenu;
+    QMenu *m_moveMenu;
 
     QList<QAbstractSlider *> m_slidersPlayback;
     QList<QAbstractSlider *> m_slidersCapture;
